# Generated by Django 2.0 on 2018-01-09 05:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("schedule", "0008_calendar_slug_unique"),
        ("schedule", "0008_gfk_index"),
    ]

    operations = []
